// -*- c++ -*-
/***************************************************************************                          guicommandline.h  -  description
                             -------------------
    begin                : jeu avr 18 16:56:00 CET 2002
    copyright            : (C) 2002 by Romain Vinot
    email                : vinot@aist.enst.fr
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef _GUICOMMANDLINE_H_
#define _GUICOMMANDLINE_H_

/*
  CommandLine is the GUI interface for player interaction.
  This class takes all the input of the player and if it's a command execute it

  This class is a virtual one. It must be inherited from xcommandline or 
  qcommandline.
*/

#include <string>
#include <set>
using namespace std;

class QString;

#include "variables.h"

class Board;
class GameManager;
class GUICreature;
class GUIBoard;

class GUICommandLine
{
public:
  GUICommandLine(GUIBoard *board, GUICreature *guicrea);
  virtual ~GUICommandLine(void);
  
  virtual void endOfExecution(void)=0;

  string getPreviousCommand(void);

  virtual void commandNewGame(const char *command);
  virtual string commandView(const char *command);
  virtual string commandSelect(const char *command);
  virtual string commandMove(const char *command);
  virtual string commandEnter(const char *command);
  virtual string commandRevert(const char *command);
  virtual string commandTurn(const char *command);
  virtual string commandOpen(const char *command);
  virtual string commandClose(const char *command);
  virtual string commandAttack(const char *command);
  virtual string commandShoot(const char *command);
  virtual string commandFire(const char *command);
  virtual string commandStop(const char *command);
  virtual string commandUnjam(const char *command);
  virtual string commandLoad(const char *command);
  virtual string commandOverwatch(const char *command);
  virtual string commandTakeOrDrop(const char *command);
  virtual string commandEndTurn(const char *command);

  virtual Direction GetDirection(string txt)=0;
  virtual QString GetLevelToPlay()=0;
  virtual pair<int,Direction> GetCaseAndDirection(set<int> *cas, string txt)=0;
  virtual int GetCase(set<int> *cases, string txt)=0;
  virtual bool GetYesOrNo(string txt)=0;
  virtual void endOfGame(string msg)=0;

  virtual string commandHelp(const char *command);
  string printDirection(Direction d);
  FullDirection getDirectionType(char *d);

  virtual void printLevelInfo(QString &tit, QString &auth, QString &nar,
			      QString &obj, QString &forc, QString &cond)=0;
  virtual void printLevelInfo(void)=0;
  virtual void Write(string w, bool isCommand=false)=0;
  virtual void DrawInterface(void)=0;
  virtual void ClearListCreatures(void)=0;
  virtual void printPopupMessage(string msg)=0;

  virtual void getCommand(const char *command);
  virtual bool getMainCommands(const char *command); 
  virtual void getAllCommands(const char * command);
  virtual void getShootingCommand(const char * command);
  virtual void getFiringCommand(const char * command);

  void setState(interfaceState s);

  virtual void setObjectButtonsVisible(bool vis)=0;
protected:
  GUIBoard *guiboard;
  GUICreature *guicrea;
  
  interfaceState state;

  string previous;
};

#endif
