#ifdef _WIN32
#pragma warning (disable : 4786)
#endif

#include "qinterfaceimpl.h"

#include <qlineedit.h>
#include <qlayout.h>
#include <qlabel.h>
#include <qmultilineedit.h>
#include <qpushbutton.h>

#include "qpixmapboard.h"
#include "gamemanager.h"
#include "qcommandline.h"

/* 
 *  Constructs a QInterfaceImpl which is a child of 'parent', with the 
 *  name 'name' and widget flags set to 'f' 
 *
 */
QInterfaceImpl::QInterfaceImpl( QWidget* parent,  const char* name, WFlags fl )
  : QInterface( parent, name, fl ), cmd(0)
{
  qTurnLabel->setText("No game.");

  bTakeOrDrop->hide();
  // Add a scrollview on this frame.
  bsv = new BoardScrollView(qmap);

  // Add a layout on this frame : the scrollview must get all the size.
  QVBoxLayout* vbox = new QVBoxLayout(qmap);
  vbox->addWidget(bsv);
  vbox->activate();
}

/*  
 *  Destroys the object and frees any allocated resources
 */
QInterfaceImpl::~QInterfaceImpl()
{
    // no need to delete child widgets, Qt does it all for us
}

/* 
 * public slot
 */

void QInterfaceImpl::setCommandLine(QCommandLine *cl) 
{
  cmd = cl;
  bsv->pb->setCommandLine(cl);
}

QPixmapBoard * QInterfaceImpl::getPixmapBoard(void) {return bsv->pb;}

void QInterfaceImpl::commandToDo()
{
  if (cmd==0)
    qWarning ("Probleme avec cmd nul.\n");
  cmd->getCommand(qcommandline->text());
}

void QInterfaceImpl::select(void)
{
  man->selectOnView();
}

void QInterfaceImpl::switchView()
{
  bsv->switchView();
}

void QInterfaceImpl::setObjectButtonsVisible(bool vis)
{
  if (vis) {
    bTakeOrDrop->show();
  }
  else {
    bTakeOrDrop->hide();
  }
}

void QInterfaceImpl::customEvent(QCustomEvent *e)
{
  if (e->type() == 1000) {
    string msg = ((WriteCustomEvent *) e)->getMsg();
    qinfo->append(msg.c_str());
    qinfo->setCursorPosition(qinfo->numLines(),0);
  }
  else if (e->type() == 1001) {
    string msg = ((WriteCustomEvent *) e)->getMsg();
    qListCreatures->append(msg.c_str());
  }
  else if (e->type() == 1002) {
    string msg = "";
    WriteCustomEvent *we = (WriteCustomEvent *) e;
    msg = we->getMsg();
    qSelectedLabel->setText(msg.c_str());
  }
  else if (e->type() == 1003) {
    string msg = "";
    WriteCustomEvent *we = (WriteCustomEvent *) e;
    msg = qViewLabel->text().latin1();
    if (msg!="")
      msg += string("\n");
    msg += we->getMsg();
    qViewLabel->setText(msg.c_str());
  }
  else if (e->type() == 1010) {
    ResizeCustomEvent *ev = dynamic_cast<ResizeCustomEvent *>(e);
    int x = ev->getX();
    int y = ev->getY();
    bsv->pb->resize(x,y);
    bsv->pb->update();
  }
  else if (e->type() == 1011) {
    ButtonShowHideCustomEvent *ev=dynamic_cast<ButtonShowHideCustomEvent*>(e);
    setObjectButtonsVisible(ev->getStatus());
  }
  else if (e->type() == 1020) {
    DrawInterfaceCustomEvent *ev = dynamic_cast<DrawInterfaceCustomEvent*>(e);
    if (ev->mustDrawAll())
      cmd->GUIDrawInterface();
    else
      cmd->GUIClearListCreatures();
  }
  else
    cmd->GetEvent();
}

void QInterfaceImpl::commandAttack() {cmd->getCommand("attack");}
void QInterfaceImpl::commandShoot() {cmd->getCommand("shoot");}
void QInterfaceImpl::commandFire() {cmd->getCommand("fire");}
void QInterfaceImpl::commandClose(){cmd->getCommand("close");}
void QInterfaceImpl::commandEnter(){cmd->getCommand("enter");}
void QInterfaceImpl::commandMoveEast(){cmd->getCommand("move east");}
void QInterfaceImpl::commandMoveNorth(){cmd->getCommand("move north");}
void QInterfaceImpl::commandMoveSouth(){cmd->getCommand("move south");}
void QInterfaceImpl::commandMoveWest(){cmd->getCommand("move west");}
void QInterfaceImpl::commandMoveNorthEast(){cmd->getCommand("move north-east");}
void QInterfaceImpl::commandMoveNorthWest(){cmd->getCommand("move north-west");}
void QInterfaceImpl::commandMoveSouthEast(){cmd->getCommand("move south-east");}
void QInterfaceImpl::commandMoveSouthWest(){cmd->getCommand("move south-west");}
void QInterfaceImpl::commandOpen(){cmd->getCommand("open");}
void QInterfaceImpl::commandOverwatch(){cmd->getCommand("overwatch");}
void QInterfaceImpl::commandReload(){cmd->getCommand("load");}
void QInterfaceImpl::commandRevert(){cmd->getCommand("revert");}
void QInterfaceImpl::commandStop(){cmd->getCommand("stop");}
void QInterfaceImpl::commandTurnNorth(){cmd->getCommand("turn north");}
void QInterfaceImpl::commandTurnSouth(){cmd->getCommand("turn south");}
void QInterfaceImpl::commandTurnEast(){cmd->getCommand("turn east");}
void QInterfaceImpl::commandTurnWest(){cmd->getCommand("turn west");}
void QInterfaceImpl::commandUnjam(){cmd->getCommand("unjam");}
void QInterfaceImpl::commandEndTurn(){cmd->getCommand("endturn");}
void QInterfaceImpl::commandTakeOrDrop() {cmd->getCommand("takeordrop");}
